﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using GridUnboundColumn.Models;
using Infragistics.Web.Mvc;

namespace GridUnboundColumn.Controllers
{
    public class HomeController : Controller
    {
        public ActionResult Index()
        {
            ViewBag.Message = "This demo demonstrates the Ignite UI Grid's Unbound Column feature.";

            return View();
        }

        public ActionResult About()
        {
            ViewBag.Message = "This demo demonstrates the Ignite UI Grid's Unbound Column feature.";

            return View();
        }

        public ActionResult Demo()
        {
            ViewBag.Message = "Below the grid demonstates the feature using script definition and also demonstrating the formula property on the total column. In addition various features such as filtering and sorting are enabled to demonstrate the unbound columns interact with them as usual.";
            AdventureWorksEntities context = new AdventureWorksEntities();
            ViewBag.people = context.People.OrderBy(p => p.BusinessEntityID).Take(25).Select(p => p.FirstName + " " + p.LastName).ToList();
            return View();
        }

        public ActionResult MVCGridModel()
        {
            ViewBag.Message = "Below the grid Demonstrates Unbound columns in the Ignite UI jQuery grid defined using the server-side grim model. Also data provided by the server SetunboundValues() method and also available on the client (button below) and also demonstrating the formula property on the total column.";
            AdventureWorksEntities context = new AdventureWorksEntities();
            var employees = context.Employees.ToList().ConvertAll(e => e.ToDTO());
            var peopleNames = context.People.Take(290).ToDictionary(x => (object)x.BusinessEntityID, x => (object)(x.FirstName + " " + x.LastName));
            GridModel grid = new GridModel();
            grid.Height = "500px";
            grid.AutoCommit = false;
            grid.PrimaryKey = "BusinessEntityID";
            grid.AutoGenerateColumns = false;
            grid.LocalSchemaTransform = true;
            grid.Columns = new List<GridColumn>();
            grid.Columns.Add(new GridColumn()
            {
                Key = "BusinessEntityID",
                HeaderText = "B.E. Id",
                DataType = "number"
            });
            grid.Columns.Add(new UnboundColumn()
            {
                Key = "name",
                HeaderText = "Name",
                DataType = "string"
            });
            grid.SetUnboundValues("name", peopleNames);
            grid.Columns.Add(new GridColumn()
            {
                Key = "SickLeaveHours",
                HeaderText = "Sick Leave Hours",
                DataType = "number"
            });

            grid.Columns.Add(new GridColumn()
            {
                Key = "VacationHours",
                HeaderText = "Vacation Hours",
                DataType = "number"
            });
            grid.Columns.Add(new UnboundColumn()
            {
                Key = "total",
                HeaderText = "Total",
                DataType = "number",
                Formula = "calcTotal"
            });
            grid.DataSource = employees.AsQueryable();

        #region features
            GridFiltering filtering = new GridFiltering();
            GridSorting sorting = new GridSorting();
            GridGroupBy groupBy = new GridGroupBy();
            GridPaging paging = new GridPaging();
            grid.Features.Add(filtering);
            grid.Features.Add(sorting);
            grid.Features.Add(groupBy);
            grid.Features.Add(paging);
        #endregion //features

            return View(grid);
        }

        public ActionResult Mvc()
        {
            ViewBag.Message = "Below the grid demonstrates the feature using the MVC helper and chaining syntax, using the SetUnboundValues method to provide a list of names for the Names column and calculating the values for Total columns. Besides formula, 'Total' has a template applied for conditional formatting.";
            AdventureWorksEntities context = new AdventureWorksEntities();
            var employees = context.Employees.ToList().ConvertAll(e => e.ToDTO());
            ViewBag.people = context.People.Select(p => p.FirstName + " " + p.LastName).ToList();
            return View(employees.AsQueryable());
        }

        public ActionResult MergeUnbound()
        {
            ViewBag.Message = "Below the grid demonstrates the feature using the MVC helper and chaining syntax.";
            AdventureWorksEntities context = new AdventureWorksEntities();
            var employees = context.Employees.ToList().ConvertAll(e => e.ToDTO());
            ViewBag.people = context.People.Select(p => p.FirstName + " " + p.LastName).ToList();
            return View(employees.AsQueryable());
        }

        public JsonResult Employees()
        {
           AdventureWorksEntities context = new AdventureWorksEntities();
           var employees = context.Employees.Take(25).ToList().ConvertAll(e => e.ToDTO());
           return Json(employees, JsonRequestBehavior.AllowGet);
        }

        public JsonResult PeopleNames()
        {
            AdventureWorksEntities context = new AdventureWorksEntities();
            var ppl = context.People.Take(100).Select(p => p.FirstName + " " + p.LastName).ToList();
            return Json(ppl, JsonRequestBehavior.AllowGet);
        }
    }
}
